@@ -22,9 +22,9 @@ class ShortestPathEnv(gym.Env):
     def __init__(self, n_nodes, n_edges, weighted=True, return_graph_obs=False) -> None:
         super(ShortestPathEnv, self).__init__()
         
-        self.HAS_NOTHING = np.array([1.0], dtype=np.float32)
-        self.IS_TAKEN = np.array([2.0], dtype=np.float32)
-        self.IS_TARGET = np.array([3.0], dtype=np.float32)
+        self.HAS_NOTHING = np.array([0.0], dtype=np.float32)
+        self.IS_TAKEN = np.array([1.0], dtype=np.float32)
+        self.IS_TARGET = np.array([1.0], dtype=np.float32)
         
         self.n_nodes = n_nodes
         self.n_edges = n_edges
@@ -35,7 +35,7 @@ class ShortestPathEnv(gym.Env):
         #     node_space=gym.spaces.Box(low=0, high=4, shape=(1,)), 
         #     edge_space=gym.spaces.Box(low=0, high=1, shape=(1,)),
         #     )
-        self.observation_space = gym.spaces.Box(low=0, high=1000, shape=(n_nodes+2*n_edges+2*n_edges*2,))
+        self.observation_space = gym.spaces.Box(low=0, high=1000, shape=(2*n_nodes+2*n_edges+2*n_edges*2,))
         self.return_graph_obs = return_graph_obs
 
     def reset(self, seed=None, options={}) -> np.array:
@@ -50,17 +50,20 @@ class ShortestPathEnv(gym.Env):
         
         if self.weighted:
             delay = np.random.randint(1, 10, size=(self.n_nodes, self.n_nodes))/10.0
+            # delay = np.random.randint(1, 3, size=(self.n_nodes, self.n_nodes))*1.0
         else:
             delay = np.random.randint(10, 11, size=(self.n_nodes, self.n_nodes))/10.0
+            
         
         for u, v, d in G.edges(data=True):
             d['delay'] = delay[u, v]
         
         G = G.to_directed()
         
-        x = np.zeros((self.n_nodes, 1), dtype=np.float32) + self.HAS_NOTHING
+        x = np.zeros((self.n_nodes, 2), dtype=np.float32) + self.HAS_NOTHING
+        
         self.src, self.dest = np.random.choice(self.n_nodes, size=2, replace=False)
-        x[self.src], x[self.dest] = self.IS_TAKEN, self.IS_TARGET
+        x[self.src, 0], x[self.dest, 1] = self.IS_TAKEN, self.IS_TARGET
         self.head = self.src
         self.adj = nx.adjacency_matrix(G, weight='delay').todense()
         
@@ -69,13 +72,16 @@ class ShortestPathEnv(gym.Env):
         self.graph = gym.spaces.GraphInstance(nodes=x, edges=edge_f, edge_links=edge_index)
          
         self.optimal_solution = nx.shortest_path_length(G, source=self.src, target=self.dest, weight='delay')
+        # self.optimal_solution = 0
         
-        
+        # print('-----')
+        # print(self.graph.nodes)
         info = {'mask': self._get_mask()}
         
         if self.return_graph_obs:
             info['graph_obs'] = self.graph
         
+        
         return self._vectorize_graph(self.graph), info
     
     def _vectorize_graph(self, graph):
@@ -97,31 +103,35 @@ class ShortestPathEnv(gym.Env):
         assert self._get_mask()[action] == True, f"Mask of {action} is False!"
 
         assert action in self._get_neighbors(self.head), f"Node {action} is not a neighbor of the current path head {self.head}!"
-        assert np.isclose(self.graph.nodes[action], self.IS_TAKEN) == False, f"Node {action} is already a part of the path!"
+        assert np.isclose(self.graph.nodes[action, 0], self.IS_TAKEN) == False, f"Node {action} is already a part of the path!"
+        
         
         
         done = False
         reward = -self.adj[self.head, action]
+        info = {}
         
-        if np.isclose(self.graph.nodes[action], self.IS_TARGET):
-            # reward += 2
+        if np.isclose(self.graph.nodes[action, 1], self.IS_TARGET):
+            # reward += self.n_nodes
             done = True
-            
-        self.graph.nodes[action] = self.IS_TAKEN
-        init_head = self.head
+            info['solved'] = True
+        
+        
+        self.graph.nodes[action, 0] = self.IS_TAKEN
         self.head = action
         
-        info = {'mask': self._get_mask()}
+        info['mask'] = self._get_mask()
         if (not done) and (info['mask'].sum() == 0):
             done = True
-            reward = -10
+            reward = -self.n_nodes
+            info['solved'] = False
             
         if done:
-            info['optimal_solution'] = self.optimal_solution
-            if reward < -5:
-                info['solved'] = False
-            else:
-                info['solved'] = True
+            info['heuristic_solution'] = self.optimal_solution
+                
         
+        # print('==')
+        # print(action, reward)
+        # print(self.graph.nodes)
         return self._vectorize_graph(self.graph), reward, done, False, info
         
\ No newline at end of file
